#!/usr/bin/env python
# encoding: utf-8
"""
create_simple-catalogue_JSON.py

Created by Theresa Velden on 2012-09-27.
Copyright (c) 2012 Cornell University. All rights reserved.
"""

import sys
import os
import datetime

import json


#### GLOBAL VARIABLES ##################

movieDataFile="../data/movies.csv"
actorDataFile="../data/actors.csv"
matchingDataFile="../data/movie_actors.csv"


#### FUNCTIONS #########################

def readMovies(data_file):
	"""reads a csv file with movie data and 
	creates a dictionary
	"""
	f = open(data_file,"r")
	rawData = f.readlines()
	f.close()
	movies={}
	m=0
	for line in rawData:
		if m==0: # do not process the header line of csv file
			m+=1
		else:
			data = line.split("| |")
			title=data[1]
			movieID=data[0].replace("|","")
			if title!="":
				movies[movieID]=title.decode("utf-8") # handle unicode encoding
	return movies

	
def readActors(data_file):
	"""reads a csv file with actor data and 
	creates a dictionary
	"""
	f = open(data_file,"r")
	rawData = f.readlines()
	f.close()
	actors={}
	m=0
	for line in rawData:
		if m==0: # do not process the header line of csv file
			m+=1
		else:
			data = line.split("| |")
			name=data[1]
			birthdate=data[2].rstrip("|\r\n")
			actorID=data[0].replace("|","")
			if name!="":
				actorInfo=[]
				actorInfo.append(name.decode("utf-8"))
				actorInfo.append(birthdate)
				actors[actorID]=actorInfo

	return actors

	
def linkKeys(data_file):
	"""reads a csv file linking movie IDs with 
	actor IDs and creates a dictionary
	"""
	f = open(data_file,"r")
	rawData = f.readlines()
	f.close()
	table={}
	m=0
	for line in rawData:
		if m==0: # do not process the header line of csv file
			m+=1
		else:
			data = line.split("| |")
			actorID=data[1].replace("|\r\n","")
			movieID=data[0].replace("|","")
			if movieID not in table:
				value=[]
				value.append(actorID)
				table[movieID]=value
			else:
				table[movieID].append(actorID)
	return table

def generateJson(allMovies,allActors,table):
	""" Homework 5: needs to be extended to capture 
	all movie and actor data
	"""
	container={} 
	catalogue={}
	container['catalogue']=catalogue
	movies=[]
	catalogue['movies']=movies
	
	for movieID, movieTitle in allMovies.iteritems():
		# require movie to have some actor information
		if (movieID in table and len(table[movieID]) > 0): 
			movie=[]
			ID={}
			ID['ID']=movieID
			movie.append(ID)
			title={}
			title['title']=movieTitle
			movie.append(title)
			movies.append(movie)
		else:
			print movieID, ": this movie has no actor information"
		
	JSONfile=json.dumps(container)
	return JSONfile

allMovies = readMovies(movieDataFile)
allActors = readActors(actorDataFile)
table = linkKeys(matchingDataFile)

json_file = generateJson(allMovies,allActors,table)

if __name__ == "__main__":
	f = open('../output/simple-catalogue.json','w')
	f.write(json_file)
	f.close()



